Hello all,

I'm pinging the patch

http://gcc.gnu.org/ml/gcc-patches/2013-10/msg00056.html

##############
Index: gcc/toplev.c
===================================================================
--- gcc/toplev.c        (revision 204671)
+++ gcc/toplev.c        (working copy)
@@ -1968,11 +1968,13 @@ toplev_main (int argc, char **argv)
 
   if (warningcount || errorcount || werrorcount)
     print_ignored_options ();
-  diagnostic_finish (global_dc);
 
-  /* Invoke registered plugin callbacks if any.  */
+  /* Invoke registered plugin callbacks if any.  Some plugins could
+     emit some diagnostics here.  */
   invoke_plugin_callbacks (PLUGIN_FINISH, NULL);
 
+  diagnostic_finish (global_dc);
+
   finalize_plugins ();
   location_adhoc_data_fini (line_table);
   if (seen_error () || werrorcount)
################ gcc/ChangeLog entry

2013-11-11  Basile Starynkevitch  <bas...@starynkevitch.net>

        * toplev.c (toplev_main): Move PLUGIN_FINISH invocation before 
          diagnostic_finish.

################

Ok for trunk?

-- 
Basile STARYNKEVITCH         http://starynkevitch.net/Basile/
email: basile<at>starynkevitch<dot>net mobile: +33 6 8501 2359
8, rue de la Faiencerie, 92340 Bourg La Reine, France
*** opinions {are only mine, sont seulement les miennes} ***


Reply via email to